@@ -16,9 +16,22 @@
 # limitations under the License.
 
 # needed because of globals()[...]
-from CodernityDB.database import DatabaseException, RecordNotFound, RevConflict, PreconditionsException, \
-    RecordDeleted, DatabaseConflict, DatabasePathException, DatabaseIsNotOpened
-from CodernityDB.index import IndexException, IndexNotFoundException, ReindexException, TryReindexException, ElemNotFound, DocIdNotFound, IndexConflict, IndexPreconditionsException
+from CodernityDB.database import (DatabaseException,
+                                  RecordNotFound,
+                                  RevConflict,
+                                  PreconditionsException,
+                                  RecordDeleted,
+                                  DatabaseConflict,
+                                  DatabasePathException,
+                                  DatabaseIsNotOpened)
+from CodernityDB.index import (IndexException,
+                               IndexNotFoundException,
+                               ReindexException,
+                               TryReindexException,
+                               ElemNotFound,
+                               DocIdNotFound,
+                               IndexConflict,
+                               IndexPreconditionsException)
 from CodernityDB.storage import StorageException
 # ^^
 import requests
@@ -65,7 +78,8 @@ def remote_excepthook(type, value, traceback):
     _traceback = getattr(value, 'remote_traceback', traceback)
     if _traceback is None:
         _traceback = traceback
-    # for some reason when _traceback it doesn't work at all (replaced by traceback)
+    # for some reason when _traceback it doesn't work at all (replaced by
+    # traceback)
     sys.__excepthook__(type, value, traceback)
 
 sys.excepthook = remote_excepthook
@@ -130,18 +144,17 @@ class Database(object):
 
     custom_header = ""
 
-    def __init__(self, path=None, url='http://localhost:9876', keep_alive=True, auth=('admin', 'password'), content_type='application/json', encoding='utf-8', connect=True):
+    def __init__(self, path=None, url='http://localhost:9876', auth=('admin', 'password'), content_type='application/json', encoding='utf-8', connect=True):
         self._path = path
         self.set_content_type(content_type)
         self.url = url
         self.path = path
-        self.keep_alive = keep_alive
         self.auth = auth
         self.set_encoding(encoding)
         self.session = None
         if connect:
             self.connect()
-            #self.initialize(path, makedir=False)
+            # self.initialize(path, makedir=False)
 
     @property
     def path(self):
@@ -192,7 +205,7 @@ class Database(object):
         url = "%s/%s" % (self.url, function)
         data = self.__dumps(data)
         result = self.session.post(url, headers=headers,
-                                   auth=self.auth, data=data, prefetch=False)
+                                   auth=self.auth, data=data, stream=True)
         if not result.status_code == requests.codes.ok:
             raise_proper_exception(result, self.__loads)
         return result.raw.read()
@@ -212,7 +225,6 @@ class Database(object):
 
     def connect(self):
         self.session = requests.session()
-        self.session.config['keep_alive'] = self.keep_alive
         res = self.check_connection()
         if res:
             self.remote_init()
